@@ -8,7 +8,7 @@
 
 import sys
 import argparse
-from loguru import logger
+import logging
 from fastrun import __description__, __version__
 from fastrun.common.command import init_parser_command, main_command
 from fastrun.common.scaffold import main_scaffold, init_parser_scaffold
@@ -33,5 +33,5 @@ def main():
         if parser.parse_args().version:
             print(f"version：{__version__}")
     else:
-        logger.error(f"{sys.argv[1:]}")
+        logging.error(f"{sys.argv[1:]}")
         raise Exception
